95 percent confidence limits and total number of observations for the lower and the upper reference limit (ranging from lower.lim.low to lower.lim.upp for the lower reference limit, and from upper.lim.low to upper.lim.upp for the upper reference limit)
Arguments
n
number of observations
lower.limit
positive number indicating the lower limit of the reference interval
upper.limit
positive number indicating the upper limit of the reference interval
lognormal
Boolean indicating whether a lognormal distribution should be assumed
apply.rounding
Boolean indicating whether the confidence limits should be rounded
Details
The confidence limits depend on the reference range (upper minus lower limit), and are proportional to 1/sqrt(n).
The coefficients used in this function have been determined by 100,000 Monte-Carlo simulations for sample sizes between n = 200 and n = 2,000 based on a standard normal distribution.