Learn R Programming

reflimR (version 1.0.6)

permissible_uncertainty: Tolerance intervals of estimated and target limits

Description

Returns the permissible uncertainty of reference limits.

Usage

permissible_uncertainty(lower.limit, upper.limit, apply.rounding = TRUE)

Value

Tolerance intervals for the lower and upper reference limits (ranging from lower.lim.low to lower.lim.upp for the lower reference limit and from upper.lim.low to upper.lim.upp for the upper reference limit)

Arguments

lower.limit

positive number indicating the lower limit of the reference interval

upper.limit

positive number indicating the upper limit of the reference interval

apply.rounding

Boolean indicating whether the tolerance limits should be rounded

Details

The tolerance limits (also called equivalence limits) indicate the permissible uncertainty of a reference limit from a medical point of view (in contrast to the confidence interval, which reflects the statistical point of view). The calculation is based on a recommendation made by the DGKL [1, 2].

References

1. Haeckel R et al. Permissible limits for uncertainty of measurement in laboratory medicine. Clin Chem Lab Med 2015;53:1161–71. tools:::Rd_expr_doi("10.1515/cclm-2014-0874").

2. Haeckel R et al. Equivalence limits of reference intervals for partitioning of population data. J Lab Med 2016; 40: 199-205. tools:::Rd_expr_doi("10.1515/labmed-2016-0002").

Examples

Run this code
permissible_uncertainty(lower.limit = 10, upper.limit = 50)
permissible_uncertainty(10, 50, FALSE)

Run the code above in your browser using DataLab