Test names (analytes), units and reference limits from a textbook.
Usage
targetvalues
Arguments
Format
A data frame with 8 rows and 6 columns:
analyte
short name of the analyte
unit
measuring unit
ll.female, ul.female
lower and upper reference limits for women
ll.male, ul.male
lower and upper reference limits for men
Details
The table was created from the data in the textbook (web version 2023, https://www.clinical-laboratory-diagnostics.com). Missing data (i.e. the lower limits for ALT, AST and GGT) were supplemented from the product sheets of the respective tests.