powered by
Rounds a quantitative laboratory result to a reasonable number of decimal places.
adjust_digits(x)
List containing a rounded value of x and the number of decimal places
numeric
adjust_digits(0.001234) adjust_digits(0) adjust_digits(-12.34) adjust_digits(5.4321)$digits
Run the code above in your browser using DataLab